@@ -205,6 +205,9 @@ class Vyos(Main):  # Vyos/EdgeOS specific commands
     def commit(self):
         self.SSHConnection.commit()
         return ("Committed")
+    
+    def whois_dn42(self, query):
+        return self.SSHConnection.send_command("whois -h whois.dn42 {}" .format(query))
 
     def save_config(self):
         return self.SSHConnection.send_command("save")
